function avgperf = demo(root)
    % This example is a simple demo to illustrate the use of provided
    % functions. It trains a linear SVM for each label to classify SIFT
    % which are inside (positive examples) or outside (negative examples) 
    % the label region. At test time, a pixel receive for each label the
    % corresponding classification score.

    % set up paths
    addpath(fullfile('3rdparty', 'dense_sift'));
    addpath(fullfile('3rdparty', 'liblinear', 'matlab'));
    if ~exist('train', 'file')
        make;
    end

    % load parameters
    params = ssem_set_params_sub(root);

    % load splits and videos        
    splits = ssem_load_splits(params);
    vids = cat(2, splits{:});    
    
    % Load ground truth annotations
    annots = ssem_load_annots(params, vids); 
    
    % Extract features
    nvids   = length(vids);
    nsplits = length(splits);
    nlabels = length(params.annots.labels);
    ngroups = length(params.annots.visuGroups);
                   
    posSIFT = cell(nvids, nlabels);
    negSIFT = cell(nvids, nlabels);
    for i = 1 : nvids
        fprintf('Extracting features for video %d/%d...\n', i, nvids);
        
        % The background image
        back = ssem_load_back(params, vids{i});
        
        % Binary labels for 'labelID'
        labels = ssem_unpack_annot(annots{i});
        
        % Extract mean SIFT for each label
        [posSIFT(i, :) negSIFT(i, :)] = get_features(back, labels);        
    end    

    % Train and test models
    perf = cell(nsplits, ngroups);
    model  = cell(1, nsplits);
    for i = 1 : nsplits
        fprintf('Testing on split %d:\n', i);

        % Leave one out setting: test on i^th split, train on the rest
        I = 1 : nsplits;
        I(i) = [];

        % Find video IDs
        vidIDs = ssem_getIDs(params, cat(2, splits{I}));
        
        % Train a model on features extracted from videos of the split
        model{i} = train_dummy_model(params, posSIFT(vidIDs, :), negSIFT(vidIDs, :));
        
        % Compute pixel-wise score for each labels
        nvids = length(splits{i});
        scores = cell(1, nvids);
        for j = 1 : nvids
            fprintf('Testing on video %d/%d...\n', j, nvids);
            scores{j} = test_dummy_model(params, model{i}, splits{i}{j});    
        end

        % Compute performance
        perf(i, :) = ssem_get_perf_split(params, splits{i}, scores);
    end
    
    % Display performances
    avgperf = ssem_display_perf(params, perf);
end





