function adaptive_background(params, input_dir, output_dir, K)
    files = dir(fullfile(input_dir, '*.jpg'));    
    
    [s, m] = mkdir(output_dir);

    file = fullfile(output_dir, sprintf('gmm_%d.mat', K));
    if exist(file, 'file') == 2
        load(file, 'sigma', 'mu', 'weights');
        fprintf('Initial GMM loaded from %s\n', file);    
    else        
        n_img = min(params.img_per_mixt * K, length(files));
        img = cell(1, n_img);
        for i = 1 : n_img
            img{i} = imresize(double(imread(fullfile(input_dir, files(i).name))), params.adptbck_imsize);
            if size(img{i}, 3) == 1
                img{i} = repmat(img{i}, [1 1 3]);
            end
        end
        img = cat(4, img{:});
        
        h = size(img, 1);
        w = size(img, 2);
        sigma = zeros(h, w, 3, K);
        mu = zeros(h, w, 3, K);
        weights = zeros(h, w, K);
        for x = 1 : w
            %fprintf('Progress: %d%%\n', round((x-1)*100/w));
            for y = 1 : h
                data = double(reshape(img(y, x, :, :), 3, n_img))' + rand(n_img, 3) * 0.001;            
                gmm = gmdistribution.fit(data, K, 'CovType', 'diagonal', 'Regularize', eps);            
                sigma(y, x, :, :) = reshape(gmm.Sigma, [1 1 3 K]);
                mu(y, x, :, :) = reshape(gmm.mu', [1 1 3 K]);
                weights(y, x, :) = gmm.PComponents;                       
            end
        end    
        save(file, 'sigma', 'mu', 'weights', '-v7.3');
    end
    sigma = max(sigma, params.min_sigma);
      
    for i = 1 : length(files)    
        %fprintf('Img %d/%d\n', i, length(files));
        origimg = double(imread(fullfile(input_dir, files(i).name)));
        origw = size(origimg, 2);
        origh = size(origimg, 1);
        img = uint8(max(min(round(imresize(origimg, params.adptbck_imsize)), 255), 0));
        if size(img, 3) == 1
            img = repmat(img, [1 1 3]);
        end
            
        [sigma mu weights foreground] = update_bckgnd(double(img), params.alpha, params.T, sigma, mu, weights);   

        foreground = imfilter(foreground, fspecial('gaussian', 6, 2));            
        foreground = tanh((foreground-0.7) * 20);
        foreground = imresize(foreground, [origh origw]);
        foreground = min(max(foreground, 0), 1);                        
        imwrite(uint8(min(max(round(foreground*255), 0), 255)), fullfile(output_dir, files(i).name))            
    end        
end
