function extract_backs(params)    
    vidsDir = fullfile(params.root, 'vids');
    vids = dir(vidsDir);
    for i = 1 : length(vids)
        if ~vids(i).isdir
            extract_back(params, vids(i).name);
        end
    end
end


function vid = extract_back(params, vidname)
    viddir = fullfile(params.root, 'vids');  
    vidfile = fullfile(viddir, vidname);
    [~, vid] = fileparts(vidname);
    vid = strrep(vid, '-', '_');
    
    tmpdir = fullfile(params.root, 'tmp', vid);   
    
    fprintf('Processing %s\n', vid);       
        
    [~, ~] = mkdir(fullfile(tmpdir));
    
    [~, ~, ext] = fileparts(vidfile);
    isStillImage = strcmp(ext, '.jpg'); 
    
    % Extract images        
    imgdir = fullfile(tmpdir, 'img');
    [~, ~] = mkdir(fullfile(imgdir));
    if exist(fullfile(imgdir, 'done'), 'file') ~= 2        
        fprintf('Extracting images...\n');
        if isStillImage
            copyfile(vidfile, fullfile(imgdir, 'frame000001.jpg'));
            fclose(fopen(fullfile(imgdir, 'done'), 'wt'));
        else            
            [status result] = system(sprintf('ffmpeg -i "%s" -y -an -sameq -f image2 -deinterlace %s/frame%%06d.jpg', vidfile, fullfile(imgdir)));
            if status == 0
                fclose(fopen(fullfile(imgdir, 'done'), 'wt'));
            else
                error(result);
            end
        end
    end
    
    % Extract background
    bckdir = fullfile(tmpdir, 'bck');
    [~, ~] = mkdir(fullfile(bckdir));
    if exist(fullfile(bckdir, 'done'), 'file') ~= 2        
        fprintf('Extracting background...\n');
        if ~isStillImage
            adaptive_background(params, imgdir, bckdir, 5);
        else            
            img = imread(fullfile(imgdir, 'frame000001.jpg'));
            img(:) = 1;
            imwrite(img, fullfile(bckdir, 'frame000001.jpg'));
        end
        fclose(fopen(fullfile(bckdir, 'done'), 'wt'));
    end
    
    % Compute clean background image    
    load(fullfile(params.root, 'annots', 'splits', [vid '.mat']));
    for i = 1 : length(vids)
        if length(vids) ~= 1
            backame = sprintf('%s.%d.jpg', vid, i);
        else
            backame = [vid '.jpg'];
        end
        file = fullfile(params.root, 'annots', 'back', backame);
        if exist(file, 'file') ~= 2 
            fprintf('Computing clean background for split %d/%d...\n', i, length(vids));
            img = get_back_from_selected(params, vid, vids(i).backimg);
            imwrite(img, file);
        end
    end
end
